@@ -2,6 +2,7 @@
 namespace Elementor;
 
 use Elementor\Modules\DynamicTags\Module as TagsModule;
+use Elementor\Modules\Promotions\Controls\Promotion_Control;
 
 if ( ! defined( 'ABSPATH' ) ) {
 	exit; // Exit if accessed directly.
@@ -41,7 +42,7 @@ class Widget_Video extends Widget_Base {
 	 * @return string Widget title.
 	 */
 	public function get_title() {
-		return __( 'Video', 'elementor' );
+		return esc_html__( 'Video', 'elementor' );
 	}
 
 	/**
@@ -85,7 +86,29 @@ class Widget_Video extends Widget_Base {
 	 * @return array Widget keywords.
 	 */
 	public function get_keywords() {
-		return [ 'video', 'player', 'embed', 'youtube', 'vimeo', 'dailymotion' ];
+		return [ 'video', 'player', 'embed', 'youtube', 'vimeo', 'dailymotion', 'videopress' ];
+	}
+
+	protected function is_dynamic_content(): bool {
+		return false;
+	}
+
+	/**
+	 * Get style dependencies.
+	 *
+	 * Retrieve the list of style dependencies the widget requires.
+	 *
+	 * @since 3.24.0
+	 * @access public
+	 *
+	 * @return array Widget style dependencies.
+	 */
+	public function get_style_depends(): array {
+		return [ 'widget-video' ];
+	}
+
+	public function has_widget_inner_wrapper(): bool {
+		return ! Plugin::$instance->experiments->is_feature_active( 'e_optimized_markup' );
 	}
 
 	/**
@@ -93,36 +116,38 @@ class Widget_Video extends Widget_Base {
 	 *
 	 * Adds different input fields to allow the user to change and customize the widget settings.
 	 *
-	 * @since 1.0.0
+	 * @since 3.1.0
 	 * @access protected
 	 */
-	protected function _register_controls() {
+	protected function register_controls() {
 		$this->start_controls_section(
 			'section_video',
 			[
-				'label' => __( 'Video', 'elementor' ),
+				'label' => esc_html__( 'Video', 'elementor' ),
 			]
 		);
 
 		$this->add_control(
 			'video_type',
 			[
-				'label' => __( 'Source', 'elementor' ),
+				'label' => esc_html__( 'Source', 'elementor' ),
 				'type' => Controls_Manager::SELECT,
 				'default' => 'youtube',
 				'options' => [
-					'youtube' => __( 'YouTube', 'elementor' ),
-					'vimeo' => __( 'Vimeo', 'elementor' ),
-					'dailymotion' => __( 'Dailymotion', 'elementor' ),
-					'hosted' => __( 'Self Hosted', 'elementor' ),
+					'youtube' => esc_html__( 'YouTube', 'elementor' ),
+					'vimeo' => esc_html__( 'Vimeo', 'elementor' ),
+					'dailymotion' => esc_html__( 'Dailymotion', 'elementor' ),
+					'videopress' => esc_html__( 'VideoPress', 'elementor' ),
+					'hosted' => esc_html__( 'Self Hosted', 'elementor' ),
 				],
+				'frontend_available' => true,
 			]
 		);
 
 		$this->add_control(
 			'youtube_url',
 			[
-				'label' => __( 'Link', 'elementor' ),
+				'label' => esc_html__( 'Link', 'elementor' ),
 				'type' => Controls_Manager::TEXT,
 				'dynamic' => [
 					'active' => true,
@@ -131,19 +156,23 @@ class Widget_Video extends Widget_Base {
 						TagsModule::URL_CATEGORY,
 					],
 				],
-				'placeholder' => __( 'Enter your URL', 'elementor' ) . ' (YouTube)',
+				'placeholder' => esc_html__( 'Enter your URL', 'elementor' ) . ' (YouTube)',
 				'default' => 'https://www.youtube.com/watch?v=XHOmBV4js_E',
 				'label_block' => true,
 				'condition' => [
 					'video_type' => 'youtube',
 				],
+				'ai' => [
+					'active' => false,
+				],
+				'frontend_available' => true,
 			]
 		);
 
 		$this->add_control(
 			'vimeo_url',
 			[
-				'label' => __( 'Link', 'elementor' ),
+				'label' => esc_html__( 'Link', 'elementor' ),
 				'type' => Controls_Manager::TEXT,
 				'dynamic' => [
 					'active' => true,
@@ -152,19 +181,22 @@ class Widget_Video extends Widget_Base {
 						TagsModule::URL_CATEGORY,
 					],
 				],
-				'placeholder' => __( 'Enter your URL', 'elementor' ) . ' (Vimeo)',
+				'placeholder' => esc_html__( 'Enter your URL', 'elementor' ) . ' (Vimeo)',
 				'default' => 'https://vimeo.com/235215203',
 				'label_block' => true,
 				'condition' => [
 					'video_type' => 'vimeo',
 				],
+				'ai' => [
+					'active' => false,
+				],
 			]
 		);
 
 		$this->add_control(
 			'dailymotion_url',
 			[
-				'label' => __( 'Link', 'elementor' ),
+				'label' => esc_html__( 'Link', 'elementor' ),
 				'type' => Controls_Manager::TEXT,
 				'dynamic' => [
 					'active' => true,
@@ -173,22 +205,25 @@ class Widget_Video extends Widget_Base {
 						TagsModule::URL_CATEGORY,
 					],
 				],
-				'placeholder' => __( 'Enter your URL', 'elementor' ) . ' (Dailymotion)',
+				'placeholder' => esc_html__( 'Enter your URL', 'elementor' ) . ' (Dailymotion)',
 				'default' => 'https://www.dailymotion.com/video/x6tqhqb',
 				'label_block' => true,
 				'condition' => [
 					'video_type' => 'dailymotion',
 				],
+				'ai' => [
+					'active' => false,
+				],
 			]
 		);
 
 		$this->add_control(
 			'insert_url',
 			[
-				'label' => __( 'External URL', 'elementor' ),
+				'label' => esc_html__( 'External URL', 'elementor' ),
 				'type' => Controls_Manager::SWITCHER,
 				'condition' => [
-					'video_type' => 'hosted',
+					'video_type' => [ 'hosted', 'videopress' ],
 				],
 			]
 		);
@@ -196,7 +231,7 @@ class Widget_Video extends Widget_Base {
 		$this->add_control(
 			'hosted_url',
 			[
-				'label' => __( 'Choose File', 'elementor' ),
+				'label' => esc_html__( 'Choose Video File', 'elementor' ),
 				'type' => Controls_Manager::MEDIA,
 				'dynamic' => [
 					'active' => true,
@@ -204,9 +239,11 @@ class Widget_Video extends Widget_Base {
 						TagsModule::MEDIA_CATEGORY,
 					],
 				],
-				'media_type' => 'video',
+				'media_types' => [
+					'video',
+				],
 				'condition' => [
-					'video_type' => 'hosted',
+					'video_type' => [ 'hosted', 'videopress' ],
 					'insert_url' => '',
 				],
 			]
@@ -215,7 +252,7 @@ class Widget_Video extends Widget_Base {
 		$this->add_control(
 			'external_url',
 			[
-				'label' => __( 'URL', 'elementor' ),
+				'label' => esc_html__( 'URL', 'elementor' ),
 				'type' => Controls_Manager::URL,
 				'autocomplete' => false,
 				'options' => false,
@@ -228,8 +265,7 @@ class Widget_Video extends Widget_Base {
 						TagsModule::URL_CATEGORY,
 					],
 				],
-				'media_type' => 'video',
-				'placeholder' => __( 'Enter your URL', 'elementor' ),
+				'placeholder' => esc_html__( 'Enter your URL', 'elementor' ),
 				'condition' => [
 					'video_type' => 'hosted',
 					'insert_url' => 'yes',
@@ -237,35 +273,61 @@ class Widget_Video extends Widget_Base {
 			]
 		);
 
+		$this->add_control(
+			'videopress_url',
+			[
+				'label' => esc_html__( 'URL', 'elementor' ),
+				'type' => Controls_Manager::TEXT,
+				'label_block' => true,
+				'show_label' => false,
+				'default' => 'https://videopress.com/v/ZCAOzTNk',
+				'dynamic' => [
+					'active' => true,
+					'categories' => [
+						TagsModule::POST_META_CATEGORY,
+						TagsModule::URL_CATEGORY,
+					],
+				],
+				'placeholder' => esc_html__( 'VideoPress URL', 'elementor' ),
+				'ai' => [
+					'active' => false,
+				],
+				'condition' => [
+					'video_type' => 'videopress',
+					'insert_url' => 'yes',
+				],
+
+			]
+		);
+
 		$this->add_control(
 			'start',
 			[
-				'label' => __( 'Start Time', 'elementor' ),
+				'label' => esc_html__( 'Start Time', 'elementor' ),
 				'type' => Controls_Manager::NUMBER,
-				'description' => __( 'Specify a start time (in seconds)', 'elementor' ),
-				'condition' => [
-					'loop' => '',
-				],
+				'description' => esc_html__( 'Specify a start time (in seconds)', 'elementor' ),
+				'frontend_available' => true,
+				'separator' => 'before',
 			]
 		);
 
 		$this->add_control(
 			'end',
 			[
-				'label' => __( 'End Time', 'elementor' ),
+				'label' => esc_html__( 'End Time', 'elementor' ),
 				'type' => Controls_Manager::NUMBER,
-				'description' => __( 'Specify an end time (in seconds)', 'elementor' ),
+				'description' => esc_html__( 'Specify an end time (in seconds)', 'elementor' ),
 				'condition' => [
-					'loop' => '',
 					'video_type' => [ 'youtube', 'hosted' ],
 				],
+				'frontend_available' => true,
 			]
 		);
 
 		$this->add_control(
 			'video_options',
 			[
-				'label' => __( 'Video Options', 'elementor' ),
+				'label' => esc_html__( 'Video Options', 'elementor' ),
 				'type' => Controls_Manager::HEADING,
 				'separator' => 'before',
 			]
@@ -274,62 +336,73 @@ class Widget_Video extends Widget_Base {
 		$this->add_control(
 			'autoplay',
 			[
-				'label' => __( 'Autoplay', 'elementor' ),
+				'label' => esc_html__( 'Autoplay', 'elementor' ),
+				'description' => sprintf(
+					/* translators: 1: `<a>` opening tag, 2: `</a>` closing tag. */
+					esc_html__( 'Note: Autoplay is affected by %1$s Google’s Autoplay policy %2$s on Chrome browsers.', 'elementor' ),
+					'<a href="https://developers.google.com/web/updates/2017/09/autoplay-policy-changes" target="_blank">',
+					'</a>'
+				),
 				'type' => Controls_Manager::SWITCHER,
+				'frontend_available' => true,
 			]
 		);
 
 		$this->add_control(
 			'play_on_mobile',
 			[
-				'label' => __( 'Play On Mobile', 'elementor' ),
+				'label' => esc_html__( 'Play On Mobile', 'elementor' ),
 				'type' => Controls_Manager::SWITCHER,
 				'condition' => [
 					'autoplay' => 'yes',
 				],
+				'frontend_available' => true,
 			]
 		);
 
 		$this->add_control(
 			'mute',
 			[
-				'label' => __( 'Mute', 'elementor' ),
+				'label' => esc_html__( 'Mute', 'elementor' ),
 				'type' => Controls_Manager::SWITCHER,
+				'frontend_available' => true,
 			]
 		);
 
 		$this->add_control(
 			'loop',
 			[
-				'label' => __( 'Loop', 'elementor' ),
+				'label' => esc_html__( 'Loop', 'elementor' ),
 				'type' => Controls_Manager::SWITCHER,
 				'condition' => [
 					'video_type!' => 'dailymotion',
 				],
+				'frontend_available' => true,
 			]
 		);
 
 		$this->add_control(
 			'controls',
 			[
-				'label' => __( 'Player Controls', 'elementor' ),
+				'label' => esc_html__( 'Player Controls', 'elementor' ),
 				'type' => Controls_Manager::SWITCHER,
-				'label_off' => __( 'Hide', 'elementor' ),
-				'label_on' => __( 'Show', 'elementor' ),
+				'label_off' => esc_html__( 'Hide', 'elementor' ),
+				'label_on' => esc_html__( 'Show', 'elementor' ),
 				'default' => 'yes',
 				'condition' => [
 					'video_type!' => 'vimeo',
 				],
+				'frontend_available' => true,
 			]
 		);
 
 		$this->add_control(
 			'showinfo',
 			[
-				'label' => __( 'Video Info', 'elementor' ),
+				'label' => esc_html__( 'Video Info', 'elementor' ),
 				'type' => Controls_Manager::SWITCHER,
-				'label_off' => __( 'Hide', 'elementor' ),
-				'label_on' => __( 'Show', 'elementor' ),
+				'label_off' => esc_html__( 'Hide', 'elementor' ),
+				'label_on' => esc_html__( 'Show', 'elementor' ),
 				'default' => 'yes',
 				'condition' => [
 					'video_type' => [ 'dailymotion' ],
@@ -340,22 +413,23 @@ class Widget_Video extends Widget_Base {
 		$this->add_control(
 			'modestbranding',
 			[
-				'label' => __( 'Modest Branding', 'elementor' ),
+				'label' => esc_html__( 'Modest Branding', 'elementor' ),
 				'type' => Controls_Manager::SWITCHER,
 				'condition' => [
 					'video_type' => [ 'youtube' ],
 					'controls' => 'yes',
 				],
+				'frontend_available' => true,
 			]
 		);
 
 		$this->add_control(
 			'logo',
 			[
-				'label' => __( 'Logo', 'elementor' ),
+				'label' => esc_html__( 'Logo', 'elementor' ),
 				'type' => Controls_Manager::SWITCHER,
-				'label_off' => __( 'Hide', 'elementor' ),
-				'label_on' => __( 'Show', 'elementor' ),
+				'label_off' => esc_html__( 'Hide', 'elementor' ),
+				'label_on' => esc_html__( 'Show', 'elementor' ),
 				'default' => 'yes',
 				'condition' => [
 					'video_type' => [ 'dailymotion' ],
@@ -367,23 +441,58 @@ class Widget_Video extends Widget_Base {
 		$this->add_control(
 			'yt_privacy',
 			[
-				'label' => __( 'Privacy Mode', 'elementor' ),
+				'label' => esc_html__( 'Privacy Mode', 'elementor' ),
 				'type' => Controls_Manager::SWITCHER,
-				'description' => __( 'When you turn on privacy mode, YouTube won\'t store information about visitors on your website unless they play the video.', 'elementor' ),
+				'description' => esc_html__( 'When you turn on privacy mode, YouTube/Vimeo won\'t store information about visitors on your website unless they play the video.', 'elementor' ),
 				'condition' => [
-					'video_type' => 'youtube',
+					'video_type' => [ 'youtube', 'vimeo' ],
 				],
+				'frontend_available' => true,
+			]
+		);
+
+		$this->add_control(
+			'lazy_load',
+			[
+				'label' => esc_html__( 'Lazy Load', 'elementor' ),
+				'type' => Controls_Manager::SWITCHER,
+				'conditions' => [
+					'relation' => 'or',
+					'terms' => [
+						[
+							'name' => 'video_type',
+							'operator' => '===',
+							'value' => 'youtube',
+						],
+						[
+							'relation' => 'and',
+							'terms' => [
+								[
+									'name' => 'show_image_overlay',
+									'operator' => '===',
+									'value' => 'yes',
+								],
+								[
+									'name' => 'video_type',
+									'operator' => '!==',
+									'value' => 'hosted',
+								],
+							],
+						],
+					],
+				],
+				'frontend_available' => true,
 			]
 		);
 
 		$this->add_control(
 			'rel',
 			[
-				'label' => __( 'Suggested Videos', 'elementor' ),
+				'label' => esc_html__( 'Suggested Videos', 'elementor' ),
 				'type' => Controls_Manager::SELECT,
 				'options' => [
-					'' => __( 'Current Video Channel', 'elementor' ),
-					'yes' => __( 'Any Video', 'elementor' ),
+					'' => esc_html__( 'Current Video Channel', 'elementor' ),
+					'yes' => esc_html__( 'Any Video', 'elementor' ),
 				],
 				'condition' => [
 					'video_type' => 'youtube',
@@ -395,10 +504,10 @@ class Widget_Video extends Widget_Base {
 		$this->add_control(
 			'vimeo_title',
 			[
-				'label' => __( 'Intro Title', 'elementor' ),
+				'label' => esc_html__( 'Intro Title', 'elementor' ),
 				'type' => Controls_Manager::SWITCHER,
-				'label_off' => __( 'Hide', 'elementor' ),
-				'label_on' => __( 'Show', 'elementor' ),
+				'label_off' => esc_html__( 'Hide', 'elementor' ),
+				'label_on' => esc_html__( 'Show', 'elementor' ),
 				'default' => 'yes',
 				'condition' => [
 					'video_type' => 'vimeo',
@@ -409,10 +518,10 @@ class Widget_Video extends Widget_Base {
 		$this->add_control(
 			'vimeo_portrait',
 			[
-				'label' => __( 'Intro Portrait', 'elementor' ),
+				'label' => esc_html__( 'Intro Portrait', 'elementor' ),
 				'type' => Controls_Manager::SWITCHER,
-				'label_off' => __( 'Hide', 'elementor' ),
-				'label_on' => __( 'Show', 'elementor' ),
+				'label_off' => esc_html__( 'Hide', 'elementor' ),
+				'label_on' => esc_html__( 'Show', 'elementor' ),
 				'default' => 'yes',
 				'condition' => [
 					'video_type' => 'vimeo',
@@ -423,10 +532,10 @@ class Widget_Video extends Widget_Base {
 		$this->add_control(
 			'vimeo_byline',
 			[
-				'label' => __( 'Intro Byline', 'elementor' ),
+				'label' => esc_html__( 'Intro Byline', 'elementor' ),
 				'type' => Controls_Manager::SWITCHER,
-				'label_off' => __( 'Hide', 'elementor' ),
-				'label_on' => __( 'Show', 'elementor' ),
+				'label_off' => esc_html__( 'Hide', 'elementor' ),
+				'label_on' => esc_html__( 'Show', 'elementor' ),
 				'default' => 'yes',
 				'condition' => [
 					'video_type' => 'vimeo',
@@ -437,7 +546,7 @@ class Widget_Video extends Widget_Base {
 		$this->add_control(
 			'color',
 			[
-				'label' => __( 'Controls Color', 'elementor' ),
+				'label' => esc_html__( 'Controls Color', 'elementor' ),
 				'type' => Controls_Manager::COLOR,
 				'default' => '',
 				'condition' => [
@@ -449,59 +558,87 @@ class Widget_Video extends Widget_Base {
 		$this->add_control(
 			'download_button',
 			[
-				'label' => __( 'Download Button', 'elementor' ),
+				'label' => esc_html__( 'Download Button', 'elementor' ),
 				'type' => Controls_Manager::SWITCHER,
-				'label_off' => __( 'Hide', 'elementor' ),
-				'label_on' => __( 'Show', 'elementor' ),
+				'label_off' => esc_html__( 'Hide', 'elementor' ),
+				'label_on' => esc_html__( 'Show', 'elementor' ),
 				'condition' => [
 					'video_type' => 'hosted',
 				],
 			]
 		);
 
+		$this->add_control(
+			'preload',
+			[
+				'label' => esc_html__( 'Preload', 'elementor' ),
+				'type' => Controls_Manager::SELECT,
+				'options' => [
+					'metadata' => esc_html__( 'Metadata', 'elementor' ),
+					'auto' => esc_html__( 'Auto', 'elementor' ),
+					'none' => esc_html__( 'None', 'elementor' ),
+				],
+				'description' => sprintf(
+					'%1$s <a target="_blank" href="https://go.elementor.com/preload-video/">%2$s</a>',
+					esc_html__( 'Preload attribute lets you specify how the video should be loaded when the page loads.', 'elementor' ),
+					esc_html__( 'Learn more', 'elementor' ),
+				),
+				'default' => 'metadata',
+				'condition' => [
+					'video_type' => 'hosted',
+					'autoplay' => '',
+				],
+			]
+		);
+
 		$this->add_control(
 			'poster',
 			[
-				'label' => __( 'Poster', 'elementor' ),
+				'label' => esc_html__( 'Poster', 'elementor' ),
 				'type' => Controls_Manager::MEDIA,
+				'dynamic' => [
+					'active' => true,
+				],
 				'condition' => [
 					'video_type' => 'hosted',
 				],
 			]
 		);
 
-		$this->add_control(
-			'view',
-			[
-				'label' => __( 'View', 'elementor' ),
-				'type' => Controls_Manager::HIDDEN,
-				'default' => 'youtube',
-			]
-		);
+		if ( ! Utils::has_pro() ) {
+			$this->add_control(
+				Utils::VIDEO_PLAYLIST . '_promotion',
+				[
+					'label' => esc_html__( 'Video Playlist widget', 'elementor' ),
+					'type' => Promotion_Control::TYPE,
+				]
+			);
+		}
 
 		$this->end_controls_section();
 
 		$this->start_controls_section(
 			'section_image_overlay',
 			[
-				'label' => __( 'Image Overlay', 'elementor' ),
+				'label' => esc_html__( 'Image Overlay', 'elementor' ),
 			]
 		);
 
 		$this->add_control(
 			'show_image_overlay',
 			[
-				'label' => __( 'Image Overlay', 'elementor' ),
+				'label' => esc_html__( 'Image Overlay', 'elementor' ),
 				'type' => Controls_Manager::SWITCHER,
-				'label_off' => __( 'Hide', 'elementor' ),
-				'label_on' => __( 'Show', 'elementor' ),
+				'label_off' => esc_html__( 'Hide', 'elementor' ),
+				'label_on' => esc_html__( 'Show', 'elementor' ),
+				'frontend_available' => true,
 			]
 		);
 
 		$this->add_control(
 			'image_overlay',
 			[
-				'label' => __( 'Choose Image', 'elementor' ),
+				'label' => esc_html__( 'Choose Image', 'elementor' ),
 				'type' => Controls_Manager::MEDIA,
 				'default' => [
 					'url' => Utils::get_placeholder_image_src(),
@@ -512,18 +649,7 @@ class Widget_Video extends Widget_Base {
 				'condition' => [
 					'show_image_overlay' => 'yes',
 				],
-			]
-		);
-
-		$this->add_control(
-			'lazy_load',
-			[
-				'label' => __( 'Lazy Load', 'elementor' ),
-				'type' => Controls_Manager::SWITCHER,
-				'condition' => [
-					'show_image_overlay' => 'yes',
-					'video_type!' => 'hosted',
-				],
+				'frontend_available' => true,
 			]
 		);
 
@@ -532,7 +658,6 @@ class Widget_Video extends Widget_Base {
 			[
 				'name' => 'image_overlay', // Usage: `{name}_size` and `{name}_custom_dimension`, in this case `image_overlay_size` and `image_overlay_custom_dimension`.
 				'default' => 'full',
-				'separator' => 'none',
 				'condition' => [
 					'show_image_overlay' => 'yes',
 				],
@@ -542,9 +667,12 @@ class Widget_Video extends Widget_Base {
 		$this->add_control(
 			'show_play_icon',
 			[
-				'label' => __( 'Play Icon', 'elementor' ),
+				'label' => esc_html__( 'Play Icon', 'elementor' ),
 				'type' => Controls_Manager::SWITCHER,
 				'default' => 'yes',
+				'label_off' => esc_html__( 'Hide', 'elementor' ),
+				'label_on' => esc_html__( 'Show', 'elementor' ),
+				'separator' => 'before',
 				'condition' => [
 					'show_image_overlay' => 'yes',
 					'image_overlay[url]!' => '',
@@ -552,14 +680,49 @@ class Widget_Video extends Widget_Base {
 			]
 		);
 
+		$this->add_control(
+			'play_icon',
+			[
+				'label' => esc_html__( 'Icon', 'elementor' ),
+				'type' => Controls_Manager::ICONS,
+				'fa4compatibility' => 'icon',
+				'skin' => 'inline',
+				'label_block' => false,
+				'skin_settings' => [
+					'inline' => [
+						'none' => [
+							'label' => 'Default',
+							'icon' => 'eicon-play',
+						],
+						'icon' => [
+							'icon' => 'eicon-star',
+						],
+					],
+				],
+				'recommended' => [
+					'fa-regular' => [
+						'play-circle',
+					],
+					'fa-solid' => [
+						'play',
+						'play-circle',
+					],
+				],
+				'condition' => [
+					'show_image_overlay' => 'yes',
+					'show_play_icon!' => '',
+				],
+			]
+		);
+
 		$this->add_control(
 			'lightbox',
 			[
-				'label' => __( 'Lightbox', 'elementor' ),
+				'label' => esc_html__( 'Lightbox', 'elementor' ),
 				'type' => Controls_Manager::SWITCHER,
 				'frontend_available' => true,
-				'label_off' => __( 'Off', 'elementor' ),
-				'label_on' => __( 'On', 'elementor' ),
+				'label_off' => esc_html__( 'Off', 'elementor' ),
+				'label_on' => esc_html__( 'On', 'elementor' ),
 				'condition' => [
 					'show_image_overlay' => 'yes',
 					'image_overlay[url]!' => '',
@@ -573,7 +736,7 @@ class Widget_Video extends Widget_Base {
 		$this->start_controls_section(
 			'section_video_style',
 			[
-				'label' => __( 'Video', 'elementor' ),
+				'label' => esc_html__( 'Video', 'elementor' ),
 				'tab' => Controls_Manager::TAB_STYLE,
 			]
 		);
@@ -581,7 +744,7 @@ class Widget_Video extends Widget_Base {
 		$this->add_control(
 			'aspect_ratio',
 			[
-				'label' => __( 'Aspect Ratio', 'elementor' ),
+				'label' => esc_html__( 'Aspect Ratio', 'elementor' ),
 				'type' => Controls_Manager::SELECT,
 				'options' => [
 					'169' => '16:9',
@@ -591,9 +754,18 @@ class Widget_Video extends Widget_Base {
 					'11' => '1:1',
 					'916' => '9:16',
 				],
+				'selectors_dictionary' => [
+					'169' => '1.77777', // 16 / 9
+					'219' => '2.33333', // 21 / 9
+					'43' => '1.33333', // 4 / 3
+					'32' => '1.5', // 3 / 2
+					'11' => '1', // 1 / 1
+					'916' => '0.5625', // 9 / 16
+				],
 				'default' => '169',
-				'prefix_class' => 'elementor-aspect-ratio-',
-				'frontend_available' => true,
+				'selectors' => [
+					'{{WRAPPER}} .elementor-wrapper' => '--video-aspect-ratio: {{VALUE}}',
+				],
 			]
 		);
 
@@ -605,26 +777,40 @@ class Widget_Video extends Widget_Base {
 			]
 		);
 
+		$this->end_controls_section();
+
+		$this->start_controls_section(
+			'section_image_overlay_style',
+			[
+				'label' => esc_html__( 'Image Overlay', 'elementor' ),
+				'tab' => Controls_Manager::TAB_STYLE,
+				'condition' => [
+					'show_image_overlay' => 'yes',
+					'show_play_icon' => 'yes',
+				],
+			]
+		);
+
 		$this->add_control(
 			'play_icon_title',
 			[
-				'label' => __( 'Play Icon', 'elementor' ),
+				'label' => esc_html__( 'Play Icon', 'elementor' ),
 				'type' => Controls_Manager::HEADING,
 				'condition' => [
 					'show_image_overlay' => 'yes',
 					'show_play_icon' => 'yes',
 				],
-				'separator' => 'before',
 			]
 		);
 
 		$this->add_control(
 			'play_icon_color',
 			[
-				'label' => __( 'Color', 'elementor' ),
+				'label' => esc_html__( 'Color', 'elementor' ),
 				'type' => Controls_Manager::COLOR,
 				'selectors' => [
 					'{{WRAPPER}} .elementor-custom-embed-play i' => 'color: {{VALUE}}',
+					'{{WRAPPER}} .elementor-custom-embed-play svg' => 'fill: {{VALUE}}',
 				],
 				'condition' => [
 					'show_image_overlay' => 'yes',
@@ -636,8 +822,9 @@ class Widget_Video extends Widget_Base {
 		$this->add_responsive_control(
 			'play_icon_size',
 			[
-				'label' => __( 'Size', 'elementor' ),
+				'label' => esc_html__( 'Size', 'elementor' ),
 				'type' => Controls_Manager::SLIDER,
+				'size_units' => [ 'px', 'em', 'rem', 'custom' ],
 				'range' => [
 					'px' => [
 						'min' => 10,
@@ -645,7 +832,9 @@ class Widget_Video extends Widget_Base {
 					],
 				],
 				'selectors' => [
+					// Not using a CSS vars because the default size value is coming from a global scss file.
 					'{{WRAPPER}} .elementor-custom-embed-play i' => 'font-size: {{SIZE}}{{UNIT}}',
+					'{{WRAPPER}} .elementor-custom-embed-play svg' => 'width: {{SIZE}}{{UNIT}}; height: {{SIZE}}{{UNIT}};',
 				],
 				'condition' => [
 					'show_image_overlay' => 'yes',
@@ -661,12 +850,13 @@ class Widget_Video extends Widget_Base {
 				'selector' => '{{WRAPPER}} .elementor-custom-embed-play i',
 				'fields_options' => [
 					'text_shadow_type' => [
-						'label' => _x( 'Shadow', 'Text Shadow Control', 'elementor' ),
+						'label' => esc_html__( 'Shadow', 'elementor' ),
 					],
 				],
 				'condition' => [
 					'show_image_overlay' => 'yes',
 					'show_play_icon' => 'yes',
+					'play_icon[library]!' => 'svg',
 				],
 			]
 		);
@@ -676,7 +866,7 @@ class Widget_Video extends Widget_Base {
 		$this->start_controls_section(
 			'section_lightbox_style',
 			[
-				'label' => __( 'Lightbox', 'elementor' ),
+				'label' => esc_html__( 'Lightbox', 'elementor' ),
 				'tab' => Controls_Manager::TAB_STYLE,
 				'condition' => [
 					'show_image_overlay' => 'yes',
@@ -689,7 +879,7 @@ class Widget_Video extends Widget_Base {
 		$this->add_control(
 			'lightbox_color',
 			[
-				'label' => __( 'Background Color', 'elementor' ),
+				'label' => esc_html__( 'Background Color', 'elementor' ),
 				'type' => Controls_Manager::COLOR,
 				'selectors' => [
 					'#elementor-lightbox-{{ID}}' => 'background-color: {{VALUE}};',
@@ -700,10 +890,11 @@ class Widget_Video extends Widget_Base {
 		$this->add_control(
 			'lightbox_ui_color',
 			[
-				'label' => __( 'UI Color', 'elementor' ),
+				'label' => esc_html__( 'UI Color', 'elementor' ),
 				'type' => Controls_Manager::COLOR,
 				'selectors' => [
 					'#elementor-lightbox-{{ID}} .dialog-lightbox-close-button' => 'color: {{VALUE}}',
+					'#elementor-lightbox-{{ID}} .dialog-lightbox-close-button svg' => 'fill: {{VALUE}}',
 				],
 			]
 		);
@@ -711,49 +902,11 @@ class Widget_Video extends Widget_Base {
 		$this->add_control(
 			'lightbox_ui_color_hover',
 			[
-				'label' => __( 'UI Hover Color', 'elementor' ),
+				'label' => esc_html__( 'UI Hover Color', 'elementor' ),
 				'type' => Controls_Manager::COLOR,
 				'selectors' => [
 					'#elementor-lightbox-{{ID}} .dialog-lightbox-close-button:hover' => 'color: {{VALUE}}',
-				],
-				'separator' => 'after',
-			]
-		);
-
-		$this->add_control(
-			'lightbox_video_width',
-			[
-				'label' => __( 'Content Width', 'elementor' ),
-				'type' => Controls_Manager::SLIDER,
-				'default' => [
-					'unit' => '%',
-				],
-				'range' => [
-					'%' => [
-						'min' => 30,
-					],
-				],
-				'selectors' => [
-					'(desktop+)#elementor-lightbox-{{ID}} .elementor-video-container' => 'width: {{SIZE}}{{UNIT}};',
-				],
-			]
-		);
-
-		$this->add_control(
-			'lightbox_content_position',
-			[
-				'label' => __( 'Content Position', 'elementor' ),
-				'type' => Controls_Manager::SELECT,
-				'frontend_available' => true,
-				'options' => [
-					'' => __( 'Center', 'elementor' ),
-					'top' => __( 'Top', 'elementor' ),
-				],
-				'selectors' => [
-					'#elementor-lightbox-{{ID}} .elementor-video-container' => '{{VALUE}}; transform: translateX(-50%);',
-				],
-				'selectors_dictionary' => [
-					'top' => 'top: 60px',
+					'#elementor-lightbox-{{ID}} .dialog-lightbox-close-button:hover svg' => 'fill: {{VALUE}}',
 				],
 			]
 		);
@@ -761,15 +914,82 @@ class Widget_Video extends Widget_Base {
 		$this->add_responsive_control(
 			'lightbox_content_animation',
 			[
-				'label' => __( 'Entrance Animation', 'elementor' ),
+				'label' => esc_html__( 'Entrance Animation', 'elementor' ),
 				'type' => Controls_Manager::ANIMATION,
 				'frontend_available' => true,
+				'separator' => 'before',
+			]
+		);
+
+		$this->add_control(
+			'deprecation_warning',
+			[
+				'type' => Controls_Manager::ALERT,
+				'alert_type' => 'danger',
+				'content' => esc_html__( 'Note: These controls have been deprecated and are only visible if they were previously in use. The video’s width and position are now set based on its aspect ratio.', 'elementor' ),
+				'separator' => 'before',
+				'condition' => [
+					'lightbox_video_width!' => '',
+					'lightbox_content_position!' => '',
+				],
+			]
+		);
+
+		// Deprecated control. Visible only if it was previously in use.
+		$this->add_control(
+			'lightbox_video_width',
+			[
+				'label' => esc_html__( 'Content Width', 'elementor' ),
+				'type' => Controls_Manager::SLIDER,
+				'size_units' => [ 'px', '%', 'em', 'rem', 'vw', 'custom' ],
+				'default' => [
+					'unit' => '%',
+				],
+				// 'selectors' => [
+				// 	'(desktop+)#elementor-lightbox-{{ID}} .elementor-video-container' => 'width: {{SIZE}}{{UNIT}};',
+				// ],
+				'condition' => [
+					'lightbox_video_width!' => '',
+					'lightbox_content_position!' => '',
+				],
+			]
+		);
+
+		// Deprecated control. Visible only if it was previously in use.
+		$this->add_control(
+			'lightbox_content_position',
+			[
+				'label' => esc_html__( 'Content Position', 'elementor' ),
+				'type' => Controls_Manager::SELECT,
+				'frontend_available' => true,
+				'options' => [
+					'' => esc_html__( 'Center', 'elementor' ),
+					'top' => esc_html__( 'Top', 'elementor' ),
+				],
+				// 'selectors' => [
+				// 	'#elementor-lightbox-{{ID}} .elementor-video-container' => '{{VALUE}}; transform: translateX(-50%);',
+				// ],
+				'selectors_dictionary' => [
+					'top' => 'top: 60px',
+				],
+				'condition' => [
+					'lightbox_video_width!' => '',
+					'lightbox_content_position!' => '',
+				],
 			]
 		);
 
 		$this->end_controls_section();
 	}
 
+	public function print_a11y_text( $image_overlay ) {
+		if ( empty( $image_overlay['alt'] ) ) {
+			echo esc_html__( 'Play Video', 'elementor' );
+		} else {
+			echo esc_html__( 'Play Video about', 'elementor' ) . ' ' . esc_attr( $image_overlay['alt'] );
+		}
+	}
+
 	/**
 	 * Render video widget output on the frontend.
 	 *
@@ -785,29 +1005,39 @@ class Widget_Video extends Widget_Base {
 
 		if ( 'hosted' === $settings['video_type'] ) {
 			$video_url = $this->get_hosted_video_url();
+		} else {
+			if ( 'videopress' === $settings['video_type'] ) {
+				$video_url = $this->get_videopress_video_url();
+			}
+
+			$embed_params = $this->get_embed_params();
+			$embed_options = $this->get_embed_options();
 		}
 
 		if ( empty( $video_url ) ) {
 			return;
 		}
 
+		if ( 'youtube' === $settings['video_type'] ) {
+			$video_html = '<div class="elementor-video"></div>';
+		}
+
 		if ( 'hosted' === $settings['video_type'] ) {
+			$this->add_render_attribute( 'video-wrapper', 'class', 'e-hosted-video' );
+
 			ob_start();
 
 			$this->render_hosted_video();
 
 			$video_html = ob_get_clean();
 		} else {
-			$embed_params = $this->get_embed_params();
-
-			$embed_options = $this->get_embed_options();
-
 			$is_static_render_mode = Plugin::$instance->frontend->is_static_render_mode();
 			$post_id = get_queried_object_id();
 
 			if ( $is_static_render_mode ) {
 				$video_html = Embed::get_embed_thumbnail_html( $video_url, $post_id );
-			} else {
+				// YouTube API requires a different markup which was set above.
+			} else if ( 'youtube' !== $settings['video_type'] ) {
 				$video_html = Embed::get_embed_html( $video_url, $embed_params, $embed_options );
 			}
 		}
@@ -820,16 +1050,12 @@ class Widget_Video extends Widget_Base {
 
 		$this->add_render_attribute( 'video-wrapper', 'class', 'elementor-wrapper' );
 
-		if ( ! $settings['lightbox'] ) {
-			$this->add_render_attribute( 'video-wrapper', 'class', 'elementor-fit-aspect-ratio' );
-		}
-
 		$this->add_render_attribute( 'video-wrapper', 'class', 'elementor-open-' . ( $settings['lightbox'] ? 'lightbox' : 'inline' ) );
 		?>
-		<div <?php echo $this->get_render_attribute_string( 'video-wrapper' ); ?>>
+		<div <?php $this->print_render_attribute_string( 'video-wrapper' ); ?>>
 			<?php
 			if ( ! $settings['lightbox'] ) {
-				echo $video_html; // XSS ok.
+				Utils::print_unescaped_internal_string( $video_html ); // XSS ok.
 			}
 
 			if ( $this->has_image_overlay() ) {
@@ -846,12 +1072,13 @@ class Widget_Video extends Widget_Base {
 						'type' => 'video',
 						'videoType' => $settings['video_type'],
 						'url' => $lightbox_url,
+						'autoplay' => $settings['autoplay'],
 						'modalOptions' => [
 							'id' => 'elementor-lightbox-' . $this->get_id(),
 							'entranceAnimation' => $settings['lightbox_content_animation'],
 							'entranceAnimation_tablet' => $settings['lightbox_content_animation_tablet'],
 							'entranceAnimation_mobile' => $settings['lightbox_content_animation_mobile'],
-							'videoAspectRatio' => $settings['aspect_ratio'],
+							'videoAspectRatio' => $settings['aspect_ratio'] ?? '169',
 						],
 					];
 
@@ -862,6 +1089,7 @@ class Widget_Video extends Widget_Base {
 					$this->add_render_attribute( 'image-overlay', [
 						'data-elementor-open-lightbox' => 'yes',
 						'data-elementor-lightbox' => wp_json_encode( $lightbox_options ),
+						'data-e-action-hash' => Plugin::instance()->frontend->create_action_hash( 'lightbox', $lightbox_options ),
 					] );
 
 					if ( Plugin::$instance->editor->is_edit_mode() ) {
@@ -870,17 +1098,31 @@ class Widget_Video extends Widget_Base {
 						] );
 					}
 				} else {
-					$this->add_render_attribute( 'image-overlay', 'style', 'background-image: url(' . Group_Control_Image_Size::get_attachment_image_src( $settings['image_overlay']['id'], 'image_overlay', $settings ) . ');' );
+					// When there is an image URL but no ID, it means the overlay image is the placeholder. In this case, get the placeholder URL.
+					if ( empty( $settings['image_overlay']['id'] && ! empty( $settings['image_overlay']['url'] ) ) ) {
+						$image_url = $settings['image_overlay']['url'];
+					} else {
+						$image_url = Group_Control_Image_Size::get_attachment_image_src( $settings['image_overlay']['id'], 'image_overlay', $settings );
+					}
+
+					$this->add_render_attribute( 'image-overlay', 'style', 'background-image: url(' . $image_url . ');' );
 				}
 				?>
-				<div <?php echo $this->get_render_attribute_string( 'image-overlay' ); ?>>
+				<div <?php $this->print_render_attribute_string( 'image-overlay' ); ?>>
 					<?php if ( $settings['lightbox'] ) : ?>
-						<?php echo Group_Control_Image_Size::get_attachment_image_html( $settings, 'image_overlay' ); ?>
+						<?php Group_Control_Image_Size::print_attachment_image_html( $settings, 'image_overlay' ); ?>
 					<?php endif; ?>
 					<?php if ( 'yes' === $settings['show_play_icon'] ) : ?>
-						<div class="elementor-custom-embed-play" role="button">
-							<i class="eicon-play" aria-hidden="true"></i>
-							<span class="elementor-screen-only"><?php echo __( 'Play Video', 'elementor' ); ?></span>
+						<div class="elementor-custom-embed-play" role="button" aria-label="<?php $this->print_a11y_text( $settings['image_overlay'] ); ?>" tabindex="0">
+							<?php
+							if ( empty( $settings['play_icon']['value'] ) ) {
+								$settings['play_icon'] = [
+									'library' => 'eicons',
+									'value' => 'eicon-play',
+								];
+							}
+							Icons_Manager::render_icon( $settings['play_icon'], [ 'aria-hidden' => 'true' ] );
+							?>
 						</div>
 					<?php endif; ?>
 				</div>
@@ -892,7 +1134,7 @@ class Widget_Video extends Widget_Base {
 	/**
 	 * Render video widget as plain content.
 	 *
-	 * Override the default behavior, by printing the video URL insted of rendering it.
+	 * Override the default behavior, by printing the video URL instead of rendering it.
 	 *
 	 * @since 1.4.5
 	 * @access public
@@ -966,6 +1208,10 @@ class Widget_Video extends Widget_Base {
 			$params['color'] = str_replace( '#', '', $settings['color'] );
 
 			$params['autopause'] = '0';
+
+			if ( ! empty( $settings['yt_privacy'] ) ) {
+				$params['dnt'] = 'true';
+			}
 		} elseif ( 'dailymotion' === $settings['video_type'] ) {
 			$params_dictionary = [
 				'controls',
@@ -979,6 +1225,10 @@ class Widget_Video extends Widget_Base {
 			$params['start'] = $settings['start'];
 
 			$params['endscreen-enable'] = '0';
+		} elseif ( 'videopress' === $settings['video_type'] ) {
+			$params_dictionary = $this->get_params_dictionary_for_videopress();
+
+			$params['at'] = $settings['start'];
 		}
 
 		foreach ( $params_dictionary as $key => $param_name ) {
@@ -1047,6 +1297,10 @@ class Widget_Video extends Widget_Base {
 			}
 		}
 
+		if ( $settings['preload'] ) {
+			$video_params['preload'] = $settings['preload'];
+		}
+
 		if ( $settings['mute'] ) {
 			$video_params['muted'] = 'muted';
 		}
@@ -1101,6 +1355,36 @@ class Widget_Video extends Widget_Base {
 		return $video_url;
 	}
 
+	/**
+	 * Get the VideoPress video URL from the current selected settings.
+	 *
+	 * @return string
+	 */
+	private function get_videopress_video_url() {
+		$settings = $this->get_settings_for_display();
+
+		if ( ! empty( $settings['insert_url'] ) ) {
+			return $settings['videopress_url'];
+		}
+
+		return $settings['hosted_url']['url'];
+	}
+
+	/**
+	 * Get the params dictionary for VideoPress videos.
+	 *
+	 * @return array
+	 */
+	private function get_params_dictionary_for_videopress() {
+		return [
+			'controls',
+			'autoplay' => 'autoPlay',
+			'mute' => 'muted',
+			'loop',
+			'play_on_mobile' => 'playsinline',
+		];
+	}
+
 	/**
 	 *
 	 * @since 2.1.0
@@ -1113,8 +1397,9 @@ class Widget_Video extends Widget_Base {
 		}
 
 		$video_params = $this->get_hosted_params();
+		/* Sometimes the video url is base64, therefore we use `esc_attr` in `src`. */
 		?>
-		<video class="elementor-video" src="<?php echo esc_url( $video_url ); ?>" <?php echo Utils::render_html_attributes( $video_params ); ?>></video>
+		<video class="elementor-video" src="<?php echo esc_attr( $video_url ); ?>" <?php Utils::print_html_attributes( $video_params ); ?>></video>
 		<?php
 	}
 }
